;;; logisticresponse.nlogo, rev 01 cr 15 jan 2005 by ralph abraham
;;; rev 02, 19 jan 2005: extract conversion funcs
;;; this is the turtle race model
;;; rev 03, 22 jan 2005
;;; rabbit model, do not move turtle to change color of a patch
;;; rev 04, 22 jan 2005
;;; add the distance function of the sup norm to quit drawing after closing within epsilon
;;; rev 05, 28 may 2006 fix little stuff (colorit failed)
;;; rev 06, 24 oct 2012, slight change to setup for rev 5.0
;;;;;;;;;;;
;;; NOTE: it is assumed that screen-edge-x = 100, screen-edge-y = 50, patch size 2x2 pixels.

globals [deltay deltau epsilon]
;;; turtles
;;; patches

;;; procedures
to init-globals
  set deltay 100 ;;; this is Graphics Window attribute: screen-size-y
  set deltau 1.0 ;;; from def of logistic map family
  set epsilon 0.05 ;;; supdist of neighboring patches in world coords (could be a slider)
  ; note: deltaR is set by sliders for R-min, R-max
  ; xcor min and max set as attributes of Graphics Window widget
end

;;; this one creates a row of turtles
to setup
  ca
  init-globals
  crt 201 ;;; one for each patch on row pycor = 0
  init-turtles
  reset-ticks
end

to init-turtles
  let n 0  ;;; counter for turtles
  while [ n < 201 ]
    [
      ask turtle n
        [
          set heading 0
          set xcor n + 100 + 0.5 ;;; see notes on coordinate systems
          set color green
        ]
      set n n + 1
    ]
end

;;; ==============================================
;;; conversion functions, world-coords <--> turtle-screen-coords:
;;; horizontal: (R <--> x), vertical (u <--> y)
;;; ----------------------------------------------
;;; (u <-- y): u = convert( y)
to-report convert [ y ]
  let u deltau * ( y + 50.0 ) / deltay
  report u
end

;;; (u --> y): u = deconvert( y)
to-report deconvert [ u ]
  let y deltay * ( u - 0.0 ) / deltau - 50
  report y
end

;;; the logistic function: f(R, u) = Ru(1-u)
to-report logistic [ are you ]
  report are * you * ( 1 - you ) 
end

to makeit
  let m 0  ;;; counter for turtles
  let deltaR ( R-max - R-min) / 201
  let newu 0 ;;; intialize local variable
  let u 0 ;;; ditto
  ;;; let vycor 0 ;;; ditto, virtual turtle (rabbit) ycor
  while [ m < 201 ]
    [
      ask turtle m  ;;; one R, turtle at a time
        [
          ;;; this will decay the transient
          let iter 0 ;;; counter for iterations at fixed R
          let R ( R-min + m * deltaR )  ;;; control param corresp to this turtle
          ;;; set u convert ycor  ;;; convert screen coord to initial world coord, 0.5
          set u 0.5
          while [ iter < transient ] ;;; transient is the dwell set by a slider
              [
                set newu logistic R u  ;;; newu = R*u*(1-u)
                set iter iter + 1
                set u newu ;;; for next iteration
              ]
          set ycor deconvert newu ;;; move the drawing turtle within column after transient finishes
          ;;;
          ;;; this will draw the attractor
          set iter 0 ;;; reset counter for iterations at fixed R, continue from current u
          while [ iter < attractor ] ;;; attractor is the run set by a slider
              [
                set newu logistic R u  ;;; newu = R*u*(1-u)
                set ycor round deconvert newu ;;; move turtle
                set pcolor red ;;; of patch you are standing on
                set iter iter + 1
                set u newu ;;; for next iteration
              ]
          set hidden? true ;;; hide turtle
        ]    
      set m m + 1  ;;; next R, turtle
    ]
end
@#$#@#$#@
GRAPHICS-WINDOW
303
10
715
243
100
50
2.0
1
10
1
1
1
0
1
1
1
-100
100
-50
50
0
0
1
ticks
30.0

BUTTON
41
28
107
61
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
41
252
113
285
NIL
makeit
NIL
1
T
TURTLE
NIL
NIL
NIL
NIL
1

SLIDER
40
74
288
107
R-min
R-min
0
4
3.8
0.01
1
NIL
HORIZONTAL

SLIDER
40
119
287
152
R-max
R-max
0
4
3.9
0.01
1
NIL
HORIZONTAL

SLIDER
40
163
212
196
transient
transient
0
200
100
10
1
NIL
HORIZONTAL

SLIDER
40
207
212
240
attractor
attractor
0
200
150
10
1
NIL
HORIZONTAL

MONITOR
304
261
361
306
NIL
R-min
3
1
11

MONITOR
659
260
716
305
NIL
R-max
3
1
11

TEXTBOX
256
230
291
248
u=0
11
0.0
0

TEXTBOX
254
29
291
47
u = 1
11
0.0
0

TEXTBOX
507
267
542
285
R
11
0.0
0

@#$#@#$#@
Logistic Response  
by Ralph Abraham, www.visual-chaos.org

This model is a gymnasium for studying the response diagram of the logistic family of  
one-dimensional maps: X --> f(X, R) = RX(1-X), with X in [0, 1], and R fixed in [0. 4].

You select minimum and maximum values for the control parameter, R. Click the buttons  
"setup" and "go", and then see the response diagram drawn in the Graphics Window.

Experiments are suggested in the companion web page: www.visual-chaos.org/lab.

NetLogo is a marvelous tool for experiments in chaotic dynamics, as many trajectories  
may be calculated in parallel.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 30 30 240

circle 2
false
0
Circle -7500403 true true 16 16 270
Circle -16777216 true false 46 46 210

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

link
true
0
Line -7500403 true 150 0 150 300

link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 60 270 150 0 240 270 15 105 285 105
Polygon -7500403 true true 75 120 105 210 195 210 225 120 150 75

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
